/* SPDX-FileCopyrightText: 2011-2022 Blender Foundation
 *
 * SPDX-License-Identifier: Apache-2.0 */

#pragma once

#include <algorithm>

CCL_NAMESPACE_BEGIN

using std::remove;
using std::sort;
using std::stable_sort;
using std::swap;
using std::upper_bound;

CCL_NAMESPACE_END
